={{ '=' * (project|length) }}================
 {{       project          }} -- Description
={{ '=' * (project|length) }}================


{{project}} is a Python 3 ....


Documentation
-------------

Documentation for {{project}} is hosted at http://jlesquembre.github.io/{{project}}


Status
------

.. image:: https://secure.travis-ci.org/jlesquembre/{{project}}.png?branch=master
    :target: http://travis-ci.org/jlesquembre/{{project}}

.. image:: https://coveralls.io/repos/jlesquembre/{{project}}.png?branch=master
    :target: https://coveralls.io/r/jlesquembre/{{project}}?branch=master
    :alt: Coverage Status
